@@ -68,6 +68,11 @@ class HTMLReporter(ColorReporter):
 
     def output_blob(self):
         """Output to the template after all messages."""
+        if self.current_file_linted is None:
+            # There were no files checked.
+            print('[ERROR]: No files were checked.')
+            return
+
         template_f = self.linter.config.pyta_template_file
         template = Environment(loader=FileSystemLoader(TEMPLATES_DIR)).get_template(template_f)
 
@@ -86,7 +91,7 @@ class HTMLReporter(ColorReporter):
                                     reporter=self))
         print('Opening your report in a browser...')
         output_url = 'file:///{}'.format(output_path)
-        webbrowser.open(output_url)
+        webbrowser.open(output_url, new=2)
 
     @classmethod
     def _vendor_wrap(self, colour_class, text):
